@@ -157,9 +157,9 @@ class MemcachedLock(locking.Lock):
                                             expire=self.timeout,
                                             noreply=False)
             if not poked:
-                LOG.warn("Unable to heartbeat by updating key '%s' with"
-                         " extended expiry of %s seconds", self.name,
-                         self.timeout)
+                LOG.warning("Unable to heartbeat by updating key '%s' with "
+                            "extended expiry of %s seconds", self.name,
+                            self.timeout)
 
     @_translate_failures
     def get_owner(self):
@@ -217,9 +217,6 @@ class MemcachedDriver(coordination._RunWatchersMixin,
     #: String used to keep a key/member alive (until it next expires).
     STILL_ALIVE = b"It's alive!"
 
-    #: This driver requires constant periodic (heart) beatings.
-    requires_beating = True
-
     def __init__(self, member_id, parsed_url, options):
         super(MemcachedDriver, self).__init__()
         options = utils.collapse(options)
@@ -489,6 +486,9 @@ class MemcachedDriver(coordination._RunWatchersMixin,
         # Reset the acquired locks
         for lock in self._acquired_locks:
             lock.heartbeat()
+        return min(self.membership_timeout,
+                   self.leader_timeout,
+                   self.lock_timeout)
 
     @_translate_failures
     def _init_watch_group(self, group_id):
